﻿"""
Set and get server properties and authentication settings

The main server configuration properties and authentic settings are
stored inside the module variable ``properties``, that contains the
following keys:
- ``server_name``
- ``toolID``
- ``APIkey``
- ``user``

.. autosummary::

  set_property

Test server at ``imatsandbox.materialise.net``.
  
"""
import sys
PY2 = sys.version_info[0] == 2

import logging
import os

if PY2:
  import ConfigParser as configparser
else:
  import configparser

logger = logging.getLogger("API.SERVER")

config = configparser.ConfigParser()
config.read(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'configs.cfg'))

properties = dict(server_name="i.materialise.com",
                  toolID=config.get('main','toolID'),
                  APIkey=config.get('main','APIkey'),
                  user=config.get('main','user'))

def set_property(server_name=None, toolID=None, APIkey=None, user=None):
  """
  Set server properties
  
  If a property is set to ``None``, it will not be changed.
  
  :param server_name: name of the server to query
  :type server_name: str or None
  :param toolID: tool ID
  :type toolID: str
  :param APIkey: API key code
  :type APIKey: str
  :param user: user name (typically e-mail address)
  :type user: str
  """
  if server_name is not None:
    properties['server_name'] = server_name
  if toolID is not None:
    properties['toolID'] = toolID
  if APIkey is not None:
    properties['APIkey'] = APIkey
  if user is not None:
    properties['user'] = user
  
  for key in properties:
    logger.info("Server property {}={}".format(key, properties[key]))


